package com.cgi.cihr.gui;

import java.awt.Color;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;

import javax.swing.JTextPane;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyleContext;

/**
 * Class to instantiate the colour pane that we will be writing status output to.
 * 
 * @author tomas.hansson
 */
public class EISColourPane extends JTextPane {
	private AttributeSet aSetBlack;
	private AttributeSet aSetRed;
	
	/**
	 * Contructor.
	 */
	public EISColourPane()  {
		super();
		setEditable(false);
		
		StyleContext styleContext = StyleContext.getDefaultStyleContext();
		SimpleAttributeSet aSetFont = new SimpleAttributeSet();
		aSetFont.addAttribute(StyleConstants.FontSize, 12);
		aSetFont.addAttribute(StyleConstants.FontFamily, "Mono-spaced");
		aSetBlack = styleContext.addAttribute(aSetFont, StyleConstants.Foreground,
				Color.BLACK);	
		aSetRed = styleContext.addAttribute(aSetFont, StyleConstants.Foreground,
				Color.RED);		
	}
	
	/**
	 * Write info text to pane.
	 * 
	 * @param text
	 */
	public void writeInfo(String text) {
		try {
			getDocument().insertString(getDocument().getLength(), text, aSetBlack);
		} catch (BadLocationException e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Write info with newline text to pane.
	 * 
	 * @param text
	 */
	public void writelnInfo(String text) {
		writeInfo(text + "\n");
	}
	
	/**
	 * Write an error text to pane.
	 * 
	 * @param text
	 */
	public void writeError(String text) {
		try {
			getDocument().insertString(getDocument().getLength(), text, aSetRed);
		} catch (BadLocationException e) {
			e.printStackTrace();
		}
	}	
	
	/**
	 * Write an error text with newline to pane.
	 * 
	 * @param text
	 */
	public void writelnError(String text) {
		writeError(text + "\n");
	}
	
	/**
	 * Write an exception.
	 * 
	 * @param e
	 */
	public void writeException(Exception e) {
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		e.printStackTrace(new PrintStream(baos));
		writelnError(baos.toString());
	}
}
